using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Text;

namespace GridSummaries_CS
{
    interface ICommonStatus
    {
        bool IsNotRelavant { get; }
    }

    class ItemsSold
    {
        public ItemsSold(int productId, decimal unitPrice, int numberSold, IEnumerable<Part> parts)
        {
            Parts = new BindingList<Part>();
            ProductId = productId;
            UnitPrice = unitPrice;
            NumberSold = numberSold;
            if (parts != null) foreach (var p in parts) Parts.Add(p);
        }

        public int ProductId { get; private set; }
        public decimal UnitPrice { get; private set; }
        public int NumberSold { get; set; }
        public BindingList<Part> Parts { get; private set; }
    }

    class Part : ICommonStatus
    {
        public Part(int id, int count, decimal? unitCost, IEnumerable<Component> components)
        {
            Components = new BindingList<Component>();
            Id = id;
            Count = count;
            UnitCost = unitCost;
            if (components != null) foreach (var c in components) Components.Add(c);
        }

        public int Id { get; private set; }
        public int Count { get; set; }
        public decimal? UnitCost { get; set; }
        public decimal? TotalCost { get { return UnitCost * Count; } }
        public BindingList<Component> Components { get; private set; }
        [Browsable(false)]
        public bool IsNotRelavant
        {
            get { return Count == 0; }
        }
    }

    class Component : ICommonStatus
    {
        public Component(int id)
        {
            Id = id;
        }

        public Component(int id, int count, decimal? unitCost)
        {
            Id = id;
            Count = count;
            UnitCost = unitCost;
        }
        public int Id { get; private set; }
        public int Count { get; set; }
        public decimal? UnitCost { get; set; }
        public decimal? TotalCost { get { return Count * UnitCost; } }
        [Browsable(false)]
        public bool IsNotRelavant
        {
            get { return Count == 0; }
        }
    }
}
